==> plasma-framework-5.65.0.zip: plasma-framework-5.65.0/src/desktoptheme/oxygen/metadata.desktop.cmake <==
[Desktop Entry]
Name=Oxygen
Name[ar]=أكسجين
Name[bs]=kiseonik
Name[ca]=Oxygen
Name[ca@valencia]=Oxygen
Name[cs]=Oxygen
Name[da]=Oxygen
Name[de]=Oxygen
Name[en_GB]=Oxygen
Name[es]=Oxígeno
Name[et]=Oxygen
Name[eu]=Oxygen
Name[fi]=Oxygen
Name[fr]=Oxygen
Name[gd]=Ogsaidean
Name[gl]=Oxygen
Name[hu]=Oxygen
Name[ia]=Oxygen
Name[id]=Oxygen
Name[it]=Oxygen
Name[ko]=Oxygen
Name[lt]=Oxygen
Name[mr]=ऑक्सीजन
Name[nb]=Oxygen
Name[nds]=Oxygen
Name[nl]=Oxygen
Name[nn]=Oksygen
Name[pa]=ਆਕਸੀਜਨ
Name[pl]=Tlen
Name[pt]=Oxygen
Name[pt_BR]=Oxygen
Name[ru]=Oxygen
Name[sk]=Oxygen
Name[sl]=Kisik
Name[sr]=Кисеоник
Name[sr@ijekavian]=Кисеоник
Name[sr@ijekavianlatin]=Kiseonik
Name[sr@latin]=Kiseonik
Name[sv]=Oxygen
Name[tg]=Oxygen
Name[tr]=Oxygen
Name[ug]=ئوكسېگىن
Name[uk]=Oxygen
Name[x-test]=xxOxygenxx
Name[zh_CN]=Oxygen
Name[zh_TW]=Oxygen
Comment=Theme done in the Oxygen style
Comment[ar]=سمة مصنوعة بنمط «أكسجين»
Comment[bs]=Tema urađena u stilu Kiseonika
Comment[ca]=Tema fet en l'estil Oxygen
Comment[ca@valencia]=Tema fet en l'estil Oxygen
Comment[cs]=Motiv ve stylu Oxygen
Comment[da]=Tema lavet i Oxygen-stil
Comment[de]=Oberflächen-Design im Oxygen-Stil
Comment[en_GB]=Theme done in the Oxygen style
Comment[es]=Tema realizado al estilo de Oxígeno
Comment[et]=Oxygeni stiilis teema
Comment[eu]=Oxygen estiloan egindako gaia
Comment[fi]=Oxygen-tyylinen teema
Comment[fr]=Thème réalisé dans le style Oxygen
Comment[gd]=Ùrlar san stoidhle ogsaidean
Comment[gl]=Tema feito no estilo Oxygen
Comment[hu]=Oxygen-stílusú téma
Comment[ia]=Thema facite in le stilo de Oxygen
Comment[id]=Tema dikelarkan dalam gaya Oxygen
Comment[it]=Tema realizzato nello stile di Oxygen
Comment[ko]=Oxygen 스타일의 기본 테마
Comment[lt]=Oxygen stiliumi sukurtas apipavidalinimas
Comment[mr]=ऑक्सीजन शैली मध्ये शैली तयार केली
Comment[nb]=Tema laget i Oxygen-stil
Comment[nds]=Muster in den Oxygen-Stil
Comment[nl]=Thema in Oxygen-stijl
Comment[nn]=Tema laga i Oksygen-stilen
Comment[pa]=ਥੀਮ ਆਕਸੀਜਨ ਸਟਾਇਲ 'ਚ
Comment[pl]=Wystrój wzorowany na stylu Tlen
Comment[pt]=Um tema feito com o estilo Oxygen
Comment[pt_BR]=Tema criado no estilo Oxygen
Comment[ru]=Тема, выполненная в стиле Oxygen
Comment[sk]=Téma v štýle Oxygen
Comment[sl]=Tema v slogu videza Kisik
Comment[sr]=Тема урађена у стилу Кисеоника
Comment[sr@ijekavian]=Тема урађена у стилу Кисеоника
Comment[sr@ijekavianlatin]=Tema urađena u stilu Kiseonika
Comment[sr@latin]=Tema urađena u stilu Kiseonika
Comment[sv]=Tema skapat med Oxygen-stilen
Comment[tg]=Мавзӯъ дар асоси услуби Oxygen
Comment[tr]=Oxygen biçimi ile yapılmış tema
Comment[ug]=ئوكسېگىن ئۇسلۇبىدىكى ئۆرنەك
Comment[uk]=Тема в стилі Oxygen
Comment[x-test]=xxTheme done in the Oxygen stylexx
Comment[zh_CN]=Oxygen 风格的主题
Comment[zh_TW]=以 Oxygen 樣式完成的外觀主題

X-KDE-PluginInfo-Author=The Oxygen Project
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=oxygen
X-KDE-PluginInfo-Version=@KF5_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Elarun
defaultFileSuffix=.png
defaultWidth=2560
defaultHeight=1600

[ContrastEffect]
enabled=true
contrast=0.3
intensity=0.5
saturation=1.9

==> plasma-framework-5.70.1.zip: plasma-framework-5.70.1/src/desktoptheme/oxygen/metadata.desktop.cmake <==
[Desktop Entry]
Name=Oxygen
Name[ar]=أكسجين
Name[bs]=kiseonik
Name[ca]=Oxygen
Name[ca@valencia]=Oxygen
Name[cs]=Oxygen
Name[da]=Oxygen
Name[de]=Oxygen
Name[en_GB]=Oxygen
Name[es]=Oxígeno
Name[et]=Oxygen
Name[eu]=Oxygen
Name[fi]=Oxygen
Name[fr]=Oxygen
Name[gd]=Ogsaidean
Name[gl]=Oxygen
Name[hu]=Oxygen
Name[ia]=Oxygen
Name[id]=Oxygen
Name[it]=Oxygen
Name[ko]=Oxygen
Name[lt]=Oxygen
Name[lv]=Skābeklis
Name[mr]=ऑक्सीजन
Name[nb]=Oxygen
Name[nds]=Oxygen
Name[nl]=Oxygen
Name[nn]=Oksygen
Name[pa]=ਆਕਸੀਜਨ
Name[pl]=Tlen
Name[pt]=Oxygen
Name[pt_BR]=Oxygen
Name[ru]=Oxygen
Name[sk]=Oxygen
Name[sl]=Kisik (Oxygen)
Name[sr]=Кисеоник
Name[sr@ijekavian]=Кисеоник
Name[sr@ijekavianlatin]=Kiseonik
Name[sr@latin]=Kiseonik
Name[sv]=Oxygen
Name[tg]=Oxygen
Name[tr]=Oxygen
Name[ug]=ئوكسېگىن
Name[uk]=Oxygen
Name[x-test]=xxOxygenxx
Name[zh_CN]=Oxygen
Name[zh_TW]=Oxygen
Comment=Theme done in the Oxygen style
Comment[ar]=سمة مصنوعة بنمط «أكسجين»
Comment[bs]=Tema urađena u stilu Kiseonika
Comment[ca]=Tema fet en l'estil Oxygen
Comment[ca@valencia]=Tema fet en l'estil Oxygen
Comment[cs]=Motiv ve stylu Oxygen
Comment[da]=Tema lavet i Oxygen-stil
Comment[de]=Oberflächen-Design im Oxygen-Stil
Comment[en_GB]=Theme done in the Oxygen style
Comment[es]=Tema realizado al estilo de Oxígeno
Comment[et]=Oxygeni stiilis teema
Comment[eu]=Oxygen estiloan egindako gaia
Comment[fi]=Oxygen-tyylinen teema
Comment[fr]=Thème réalisé dans le style Oxygen
Comment[gd]=Ùrlar san stoidhle ogsaidean
Comment[gl]=Tema feito no estilo Oxygen
Comment[hu]=Oxygen-stílusú téma
Comment[ia]=Thema facite in le stilo de Oxygen
Comment[id]=Tema dikelarkan dalam gaya Oxygen
Comment[it]=Tema realizzato nello stile di Oxygen
Comment[ko]=Oxygen 스타일의 기본 테마
Comment[lt]=Oxygen stiliumi sukurtas apipavidalinimas
Comment[mr]=ऑक्सीजन शैली मध्ये शैली तयार केली
Comment[nb]=Tema laget i Oxygen-stil
Comment[nds]=Muster in den Oxygen-Stil
Comment[nl]=Thema in Oxygen-stijl
Comment[nn]=Tema laga i Oksygen-stilen
Comment[pa]=ਥੀਮ ਆਕਸੀਜਨ ਸਟਾਇਲ 'ਚ
Comment[pl]=Wystrój wzorowany na stylu Tlen
Comment[pt]=Um tema feito com o estilo Oxygen
Comment[pt_BR]=Tema criado no estilo Oxygen
Comment[ru]=Тема, выполненная в стиле Oxygen
Comment[sk]=Téma v štýle Oxygen
Comment[sl]=Tema v slogu videza Kisik (Oxygen)
Comment[sr]=Тема урађена у стилу Кисеоника
Comment[sr@ijekavian]=Тема урађена у стилу Кисеоника
Comment[sr@ijekavianlatin]=Tema urađena u stilu Kiseonika
Comment[sr@latin]=Tema urađena u stilu Kiseonika
Comment[sv]=Tema skapat med Oxygen-stilen
Comment[tg]=Мавзӯъ дар асоси услуби Oxygen
Comment[tr]=Oxygen biçimi ile yapılmış tema
Comment[ug]=ئوكسېگىن ئۇسلۇبىدىكى ئۆرنەك
Comment[uk]=Тема в стилі Oxygen
Comment[x-test]=xxTheme done in the Oxygen stylexx
Comment[zh_CN]=Oxygen 风格的主题
Comment[zh_TW]=以 Oxygen 樣式完成的外觀主題

X-KDE-PluginInfo-Author=The Oxygen Project
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=oxygen
X-KDE-PluginInfo-Version=@KF5_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Elarun
defaultFileSuffix=.png
defaultWidth=2560
defaultHeight=1600

[ContrastEffect]
enabled=true
contrast=0.3
intensity=0.5
saturation=1.9
